@@ -13,17 +13,18 @@ import logging
 import os
 import shutil
 
+from binaryornot.check import is_binary
 from jinja2 import FileSystemLoader
 from jinja2.environment import Environment
 
-from .exceptions import NonHTMLFileException, MissingTemplateDirException
+from .exceptions import MissingTemplateDirException
 from .utils import make_sure_path_exists, unicode_open
 
 
-def get_output_filename(template_filepath, output_dir):
+def get_output_filename(template_filepath, output_dir, force_unexpanded):
     """
     Given an input filename, return the corresponding output filename.
-    
+
     :param template_filepath: Name of template file relative to template dir,
                           e.g. art/index.html
     :param output_dir: The Complexity output directory, e.g. `www/`.
@@ -38,8 +39,8 @@ def get_output_filename(template_filepath, output_dir):
     # Base files don't have output.
     if basename.startswith('base'):
         return False
-    # Put index in the root. It's a special case.
-    elif basename == 'index.html':
+    # Put index and unexpanded templates in the root.
+    elif force_unexpanded or basename == 'index.html':
         output_filename = os.path.join(output_dir, template_filepath)
     # Put other pages in page/index.html, for better URL formatting.
     else:
@@ -51,7 +52,8 @@ def get_output_filename(template_filepath, output_dir):
         )
     return output_filename
 
-def generate_html_file(template_filepath, output_dir, env, context):
+
+def generate_html_file(template_filepath, output_dir, env, context, force_unexpanded=False):
     """
     Renders and writes a single HTML file to its corresponding output location.
 
@@ -64,10 +66,6 @@ def generate_html_file(template_filepath, output_dir, env, context):
         http://jinja.pocoo.org/docs/api/#the-context
     """
 
-    if not template_filepath.endswith('html'):
-        print('Non-HTML file found: {0}. Skipping.'.format(template_filepath))
-        return False
-
     # Ignore templates starting with "base". They're treated as special cases.
     if template_filepath.startswith('base'):
         return False
@@ -75,7 +73,7 @@ def generate_html_file(template_filepath, output_dir, env, context):
     tmpl = env.get_template(template_filepath)
     rendered_html = tmpl.render(**context)
 
-    output_filename = get_output_filename(template_filepath, output_dir)
+    output_filename = get_output_filename(template_filepath, output_dir, force_unexpanded)
     if output_filename:
         make_sure_path_exists(os.path.dirname(output_filename))
 
@@ -85,12 +83,13 @@ def generate_html_file(template_filepath, output_dir, env, context):
             return True
 
 
-def generate_html(templates_dir, output_dir, context=None):
+def generate_html(templates_dir, output_dir, context=None, unexpanded_templates=()):
     """
     Renders the HTML templates from `templates_dir`, and writes them to
     `output_dir`.
 
-    :param templates_dir: The Complexity templates directory, e.g. `project/templates/`.
+    :param templates_dir: The Complexity templates directory,
+        e.g. `project/templates/`.
     :paramtype templates_dir: directory
     :param output_dir: The Complexity output directory, e.g. `www/`.
     :paramtype output_dir: directory
@@ -116,11 +115,24 @@ def generate_html(templates_dir, output_dir, context=None):
     for root, dirs, files in os.walk(templates_dir):
         for f in files:
             # print(f)
-            template_filepath = os.path.relpath(os.path.join(root, f), templates_dir)
+            template_filepath = os.path.relpath(
+                os.path.join(root, f),
+                templates_dir
+            )
 
-            outfile = get_output_filename(template_filepath, output_dir)
-            print('Copying {0} to {1}'.format(template_filepath, outfile))
-            generate_html_file(template_filepath, output_dir, env, context)
+            force_unexpanded = template_filepath in unexpanded_templates
+            logging.debug('Is {0} in {1}? {2}'.format(
+                template_filepath,
+                unexpanded_templates,
+                force_unexpanded
+            ))
+
+            if is_binary(os.path.join(templates_dir, template_filepath)):
+                print('Non-text file found: {0}. Skipping.'.format(template_filepath))
+            else:
+                outfile = get_output_filename(template_filepath, output_dir, force_unexpanded)
+                print('Copying {0} to {1}'.format(template_filepath, outfile))
+                generate_html_file(template_filepath, output_dir, env, context, force_unexpanded)
 
 
 def generate_context(context_dir):
@@ -176,12 +188,13 @@ def copy_assets(assets_dir, output_dir):
     """
     Copies static assets over from `assets_dir` to `output_dir`.
 
-    :param assets_dir: The Complexity project assets directory, e.g. `project/assets/`.
+    :param assets_dir: The Complexity project assets directory,
+        e.g. `project/assets/`.
     :paramtype assets_dir: directory
     :param output_dir: The Complexity output directory, e.g. `www/`.
     :paramtype output_dir: directory
     """
-    
+
     assets = os.listdir(assets_dir)
     for item in assets:
         item_path = os.path.join(assets_dir, item)
@@ -191,7 +204,7 @@ def copy_assets(assets_dir, output_dir):
             new_dir = os.path.join(output_dir, item)
             print('Copying directory {0} to {1}'.format(item, new_dir))
             shutil.copytree(item_path, new_dir)
-            
+
         # Copy over files in the root of assets_dir
         if os.path.isfile(item_path):
             new_file = os.path.join(output_dir, item)
