@@ -1,5 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
+"""
+complexity.serve
+-------------------
+
+Functions for serving a static HTML website locally.
+"""
+
 import os
 import sys
 
@@ -11,14 +19,19 @@ if PY3:
 else:
     import SimpleHTTPServer as httpserver
     import SocketServer as socketserver
-    
+
 
 def serve_static_site(output_dir, port=9090):
-    """ Serve the output/ directory on port 9090. """
+    """
+    Serve a directory containing static HTML files, on a specified port.
+
+    :param output_dir: Output directory to be served.
+    """
     os.chdir(output_dir)
     Handler = httpserver.SimpleHTTPRequestHandler
 
-    # See http://stackoverflow.com/questions/16433522/socketserver-getting-rid-of-errno-98-address-already-in-use
+    # See http://stackoverflow.com/questions/16433522/socketserver-getting-rid-
+    #      of-errno-98-address-already-in-use
     socketserver.TCPServer.allow_reuse_address = True
 
     httpd = socketserver.TCPServer(("", port), Handler)
